@@ -95,7 +95,7 @@ class Package:
             if verified_postinstall_script:
                 shutil.copyfile(verified_postinstall_script, os.path.join(scripts, "postinstall"))
             logger.info(f"ensuring {scripts=} is executable (sudo chmod -R +x {scripts})")
-            Command.run(f"sudo chmod -R +x {scripts}")
+            Command.run(f"sudo -S chmod -R +x {scripts}")
 
         # 2: productbuild
         build_command = f"pkgbuild"
@@ -250,4 +250,4 @@ class Package:
         logger.info("preparing to staple")
         package = os.path.join(self.__dist, f"{self.app._name}.pkg")
         command = f"xcrun stapler staple '{package}'"
-        Command.run(command)
\ No newline at end of file
+        Command.run(command)
